GOVERNORATES_CODES_MAP = {
    1: "Cairo",
    2: "Alexandria",
    3: "Port Said",
    4: "Suez",
    11: "Damietta",
    12: "Al Daqhlia",
    13: "Al Sharkia",
    14: "Al Qaliobia",
    15: "Kafr Alsheekh",
    16: "Al Gharbia",
    17: "Al Monuefia",
    18: "Al Bohira",
    19: "Al Ismaellia",
    21: "Al Giza",
    22: "Beni Suief",
    23: "Al Fayoum",
    24: "Al minia",
    25: "Assyout",
    26: "Suhag",
    27: "Quena",
    28: "Aswan",
    29: "Luxor",
    31: "AlBahr AlAhmar",
    32: "AlWadi AlJadid",
    33: "Matrooh",
    34: "North Sinai",
    35: "South Sinai",
    88: "Outside Egypt",
}
